@@ -23,10 +23,13 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import javax.enterprise.event.Event;
+
 import org.jboss.errai.marshalling.server.MappingContextSingleton;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
+import org.mockito.Mock;
 import org.uberfire.backend.server.io.object.ObjectStorage;
 import org.uberfire.backend.server.io.object.ObjectStorageImpl;
 import org.uberfire.backend.server.spaces.SpacesAPIImpl;
@@ -39,6 +42,7 @@ import org.uberfire.preferences.shared.PreferenceScope;
 import org.uberfire.preferences.shared.PreferenceScopeFactory;
 import org.uberfire.preferences.shared.PreferenceScopeResolutionStrategy;
 import org.uberfire.preferences.shared.PreferenceScopeTypes;
+import org.uberfire.preferences.shared.event.PreferenceUpdatedEvent;
 import org.uberfire.preferences.shared.impl.DefaultPreferenceScopeResolutionStrategy;
 import org.uberfire.preferences.shared.impl.DefaultPreferenceScopeTypes;
 import org.uberfire.preferences.shared.impl.DefaultScopes;
@@ -49,9 +53,9 @@ import org.uberfire.preferences.shared.impl.PreferenceScopedValue;
 import org.uberfire.rpc.SessionInfo;
 
 import static org.junit.Assert.*;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyMap;
-import static org.mockito.Matchers.anyString;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyMap;
+import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.Mockito.*;
 
 public class PreferenceStoreImplTest {
@@ -98,7 +102,7 @@ public class PreferenceStoreImplTest {
     private PreferenceScopeResolutionStrategyInfo preferenceScopeResolutionStrategyInfo;
 
     private PreferenceStoreImpl preferenceStore;
-
+    
     @Before
     public void setup() throws IOException {
         MappingContextSingleton.get();
@@ -111,6 +115,8 @@ public class PreferenceStoreImplTest {
         final IOService ioService = mockIoService(fileSystem);
 
         ObjectStorage objectStorage = new ObjectStorageImpl(ioService);
+        
+        Event<PreferenceUpdatedEvent> preferenceUpdatedEvent = mock(Event.class);
 
         scopeTypes = new DefaultPreferenceScopeTypes(new ServerUsernameProvider(sessionInfo));
         scopeFactory = new PreferenceScopeFactoryImpl(scopeTypes);
@@ -122,7 +128,8 @@ public class PreferenceStoreImplTest {
                                                 scopeTypes,
                                                 scopeFactory,
                                                 objectStorage,
-                                                new SpacesAPIImpl()));
+                                                new SpacesAPIImpl(),
+                                                preferenceUpdatedEvent));
         storage.init();
 
         preferenceStore = spy(new PreferenceStoreImpl(storage,
