@@ -23,6 +23,7 @@ public class CreateProjectRequest extends Entity {
 
     private String groupId;
     private String version;
+    private String templateId;
 
     public CreateProjectRequest() {
     }
@@ -42,4 +43,12 @@ public class CreateProjectRequest extends Entity {
     public String getVersion() {
         return version;
     }
+
+    public String getTemplateId() {
+        return templateId;
+    }
+
+    public void setTemplateId(String templateId) {
+        this.templateId = templateId;
+    }
 }
\ No newline at end of file
